@@ -3,7 +3,7 @@ BEGIN {
   $App::EvalServer::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::EvalServer::VERSION = '0.06';
+  $App::EvalServer::VERSION = '0.07';
 }
 
 use strict;
@@ -12,8 +12,7 @@ use warnings FATAL => 'all';
 # we want instant child process reaping
 sub POE::Kernel::USE_SIGCHLD () { return 1 }
 
-use Cwd 'abs_path';
-use File::Spec::Functions qw<catdir catfile>;
+use File::Spec::Functions qw<catdir catfile rel2abs>;
 use File::Temp qw<tempdir>;
 use POE;
 use POE::Filter::JSON;
@@ -25,7 +24,7 @@ use POE::Wheel::Run;
 use POSIX qw<mkfifo>;
 use Time::HiRes qw<time>;
 
-my @inc = map { +'-I' => abs_path($_) } @INC;
+my @inc = map { +'-I' => rel2abs($_) } @INC;
 my $CHILD_PROGRAM = [
     $^X, @inc, '-MApp::EvalServer::Child',
     '-e', 'App::EvalServer::Child::run()'
